---
hide-toc: true
---

```{include} ../../README.md
:relative-images:
:end-before: <!-- start installation -->
```

```{toctree}
:maxdepth: 1
:caption: Get started
:hidden:

tutorial_for_nervous_beginners
installation
docker_images
faq
project_structure
contributing
```

```{toctree}
:maxdepth: 1
:caption: Using Coqui
:hidden:

inference
training/index
extension/index
datasets/index
```


```{toctree}
:maxdepth: 1
:caption: Main Classes
:hidden:

configuration
main_classes/trainer_api
main_classes/audio_processor
main_classes/model_api
main_classes/dataset
main_classes/gan
main_classes/speaker_manager
```


```{toctree}
:maxdepth: 1
:caption: TTS Models
:hidden:

models/glow_tts.md
models/vits.md
models/forward_tts.md
models/tacotron1-2.md
models/overflow.md
models/tortoise.md
models/bark.md
models/xtts.md
```
